/* Module: mHdrCheck.c

Version  Developer        Date     Change
-------  ---------------  -------  -----------------------
2.2      John Good        25Aug03  Added status file processing
2.1      John Good        24Apr03  Added checkFile() check
2.0      John Good        22Mar03  Changed completly to be just wrapper
				   around checkHdr() function
1.0      John Good        13Mar03  Baseline code

*/

#include <stdio.h>
#include <string.h>

#include "montage.h"
#include "fitsio.h"

int checkFile(char *filename);
int checkHdr(char *infile, int hdrflag, int hdu);

/*************************************************************************/
/*                                                                       */
/*  mHdrCheck                                                            */
/*                                                                       */
/*  This program reads a FITS file header, initializes WCS, and prints   */
/*  out the parameters associated with the projection.                   */
/*                                                                       */
/*************************************************************************/

int main(int argc, char **argv)
{
   char infile[1024];
   int  status = 0;

   fitsfile *infptr;

   fstatus = stdout;

   if (argc < 2) 
   {
      printf ("[struct stat=\"ERROR\", msg=\"Usage: %s [-s statusfile] img.fits\"]\n", argv[0]);
      exit(1);
   }

   if(strncmp(argv[1], "-s", 2) == 0)
   {
      if(argc<3 || (fstatus = fopen(argv[2], "w+")) == (FILE *)NULL)
      {
         printf ("[struct stat=\"ERROR\", msg=\"Cannot open status file: %s\"]\n",
            argv[2]);
         exit(1);
      }

      argv += 2;
      argc -= 2;

      if(argc < 2)
      {
         printf("[struct stat=\"ERROR\", msg=\"Usage: %s [-s statusfile] img.fits\"]\n", argv[0]);

         exit(0);
      }
   }


   strcpy(infile, argv[1]);

   if(checkFile(infile) != 0)
   {
      fprintf(fstatus, "[struct stat=\"ERROR\", msg=\"Usage: Image file (%s) does not exist\"]\n",
         infile);
      exit(1);
   }

   if(fits_open_file(&infptr, infile, READONLY, &status))
   {
      checkHdr(infile, 1, 0);
      fprintf(fstatus, "[struct stat=\"OK\", msg=\"Valid FITS/WCS in header file.\"]\n");
   }
   else
   {
      fits_close_file(infptr, &status);
      checkHdr(infile, 0, 0);
      fprintf(fstatus, "[struct stat=\"OK\", msg=\"Valid WCS in FITS file.\"]\n");
   }

   fflush(stdout);
   exit(0);
}
